/* markdown-actions.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __PLUGINS_MARKDOWN_ACTIONS_MARKDOWN_ACTIONS_H__
#define __PLUGINS_MARKDOWN_ACTIONS_MARKDOWN_ACTIONS_H__

#include <libpeas.h>
#include "codecore.h"
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define CODE_PLUGINS_TYPE_MARKDOWN_ACTIONS (code_plugins_markdown_actions_get_type ())
#define CODE_PLUGINS_MARKDOWN_ACTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CODE_PLUGINS_TYPE_MARKDOWN_ACTIONS, CodePluginsMarkdownActions))
#define CODE_PLUGINS_MARKDOWN_ACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CODE_PLUGINS_TYPE_MARKDOWN_ACTIONS, CodePluginsMarkdownActionsClass))
#define CODE_PLUGINS_IS_MARKDOWN_ACTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CODE_PLUGINS_TYPE_MARKDOWN_ACTIONS))
#define CODE_PLUGINS_IS_MARKDOWN_ACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CODE_PLUGINS_TYPE_MARKDOWN_ACTIONS))
#define CODE_PLUGINS_MARKDOWN_ACTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CODE_PLUGINS_TYPE_MARKDOWN_ACTIONS, CodePluginsMarkdownActionsClass))

typedef struct _CodePluginsMarkdownActions CodePluginsMarkdownActions;
typedef struct _CodePluginsMarkdownActionsClass CodePluginsMarkdownActionsClass;
typedef struct _CodePluginsMarkdownActionsPrivate CodePluginsMarkdownActionsPrivate;

struct _CodePluginsMarkdownActions {
	PeasExtensionBase parent_instance;
	CodePluginsMarkdownActionsPrivate * priv;
};

struct _CodePluginsMarkdownActionsClass {
	PeasExtensionBaseClass parent_class;
};

GType code_plugins_markdown_actions_register_type (GTypeModule * module);
VALA_EXTERN GType code_plugins_markdown_actions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CodePluginsMarkdownActions, g_object_unref)
VALA_EXTERN void code_plugins_markdown_actions_add_markdown_tag (CodePluginsMarkdownActions* self,
                                                     const gchar* tag);
VALA_EXTERN CodePluginsMarkdownActions* code_plugins_markdown_actions_new (void);
VALA_EXTERN CodePluginsMarkdownActions* code_plugins_markdown_actions_construct (GType object_type);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
