/* PaneSwitcher.c generated by valac 0.56.19, the Vala compiler
 * generated from PaneSwitcher.vala, do not modify */

/*-
 * Copyright (c) 2017 elementary LLC. (https://elementary.io)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Corentin Noël <corentin@elementary.io>
 */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define CODE_TYPE_PANE_SWITCHER (code_pane_switcher_get_type ())
#define CODE_PANE_SWITCHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CODE_TYPE_PANE_SWITCHER, CodePaneSwitcher))
#define CODE_IS_PANE_SWITCHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CODE_TYPE_PANE_SWITCHER))
#define CODE_PANE_SWITCHER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), CODE_TYPE_PANE_SWITCHER, CodePaneSwitcherIface))

typedef struct _CodePaneSwitcher CodePaneSwitcher;
typedef struct _CodePaneSwitcherIface CodePaneSwitcherIface;

struct _CodePaneSwitcherIface {
	GTypeInterface parent_iface;
	const gchar* (*get_icon_name) (CodePaneSwitcher* self);
	void (*set_icon_name) (CodePaneSwitcher* self, const gchar* value);
	const gchar* (*get_title) (CodePaneSwitcher* self);
	void (*set_title) (CodePaneSwitcher* self, const gchar* value);
};

VALA_EXTERN GType code_pane_switcher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CodePaneSwitcher, g_object_unref)
VALA_EXTERN const gchar* code_pane_switcher_get_icon_name (CodePaneSwitcher* self);
VALA_EXTERN void code_pane_switcher_set_icon_name (CodePaneSwitcher* self,
                                       const gchar* value);
VALA_EXTERN const gchar* code_pane_switcher_get_title (CodePaneSwitcher* self);
VALA_EXTERN void code_pane_switcher_set_title (CodePaneSwitcher* self,
                                   const gchar* value);
static GType code_pane_switcher_get_type_once (void);

const gchar*
code_pane_switcher_get_icon_name (CodePaneSwitcher* self)
{
	CodePaneSwitcherIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = CODE_PANE_SWITCHER_GET_INTERFACE (self);
	if (_iface_->get_icon_name) {
		return _iface_->get_icon_name (self);
	}
	return NULL;
}

void
code_pane_switcher_set_icon_name (CodePaneSwitcher* self,
                                  const gchar* value)
{
	CodePaneSwitcherIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = CODE_PANE_SWITCHER_GET_INTERFACE (self);
	if (_iface_->set_icon_name) {
		_iface_->set_icon_name (self, value);
	}
}

const gchar*
code_pane_switcher_get_title (CodePaneSwitcher* self)
{
	CodePaneSwitcherIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = CODE_PANE_SWITCHER_GET_INTERFACE (self);
	if (_iface_->get_title) {
		return _iface_->get_title (self);
	}
	return NULL;
}

void
code_pane_switcher_set_title (CodePaneSwitcher* self,
                              const gchar* value)
{
	CodePaneSwitcherIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = CODE_PANE_SWITCHER_GET_INTERFACE (self);
	if (_iface_->set_title) {
		_iface_->set_title (self, value);
	}
}

static void
code_pane_switcher_default_init (CodePaneSwitcherIface * iface,
                                 gpointer iface_data)
{
	g_object_interface_install_property (iface, g_param_spec_string ("icon-name", "icon-name", "icon-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_interface_install_property (iface, g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

 G_GNUC_NO_INLINE static GType
code_pane_switcher_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (CodePaneSwitcherIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) code_pane_switcher_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType code_pane_switcher_type_id;
	code_pane_switcher_type_id = g_type_register_static (G_TYPE_INTERFACE, "CodePaneSwitcher", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_interface_add_prerequisite (code_pane_switcher_type_id, gtk_widget_get_type ());
	return code_pane_switcher_type_id;
}

GType
code_pane_switcher_get_type (void)
{
	static gsize code_pane_switcher_type_id__once = 0;
	if (g_once_init_enter (&code_pane_switcher_type_id__once)) {
		GType code_pane_switcher_type_id;
		code_pane_switcher_type_id = code_pane_switcher_get_type_once ();
		g_once_init_leave (&code_pane_switcher_type_id__once, code_pane_switcher_type_id);
	}
	return code_pane_switcher_type_id__once;
}

