/* SelectionRange.c generated by valac 0.56.19, the Vala compiler
 * generated from SelectionRange.vala, do not modify */

/*  
 * SPDX-License-Identifier: GPL-3.0-or-later  
 * SPDX-FileCopyrightText: 2023 elementary, Inc. <https://elementary.io>  
 *
 * Authored by: Colin Kiama <colinkiama@gmail.com>
 */

#include "codecore.h"
#include <glib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

const SelectionRange SELECTION_RANGE_EMPTY = {0, 0, 0, 0};

SelectionRange*
selection_range_dup (const SelectionRange* self)
{
	SelectionRange* dup;
	dup = g_new0 (SelectionRange, 1);
	memcpy (dup, self, sizeof (SelectionRange));
	return dup;
}

void
selection_range_free (SelectionRange* self)
{
	g_free (self);
}

 G_GNUC_NO_INLINE static GType
selection_range_get_type_once (void)
{
	GType selection_range_type_id;
	selection_range_type_id = g_boxed_type_register_static ("SelectionRange", (GBoxedCopyFunc) selection_range_dup, (GBoxedFreeFunc) selection_range_free);
	return selection_range_type_id;
}

GType
selection_range_get_type (void)
{
	static gsize selection_range_type_id__once = 0;
	if (g_once_init_enter (&selection_range_type_id__once)) {
		GType selection_range_type_id;
		selection_range_type_id = selection_range_get_type_once ();
		g_once_init_leave (&selection_range_type_id__once, selection_range_type_id);
	}
	return selection_range_type_id__once;
}

