/* Settings.c generated by valac 0.56.19, the Vala compiler
 * generated from Settings.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 4 -*-*/

#include "codecore.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

 G_GNUC_NO_INLINE static GType
scratch_scratch_window_state_get_type_once (void)
{
	static const GEnumValue values[] = {{SCRATCH_SCRATCH_WINDOW_STATE_NORMAL, "SCRATCH_SCRATCH_WINDOW_STATE_NORMAL", "normal"}, {SCRATCH_SCRATCH_WINDOW_STATE_MAXIMIZED, "SCRATCH_SCRATCH_WINDOW_STATE_MAXIMIZED", "maximized"}, {SCRATCH_SCRATCH_WINDOW_STATE_FULLSCREEN, "SCRATCH_SCRATCH_WINDOW_STATE_FULLSCREEN", "fullscreen"}, {0, NULL, NULL}};
	GType scratch_scratch_window_state_type_id;
	scratch_scratch_window_state_type_id = g_enum_register_static ("ScratchScratchWindowState", values);
	return scratch_scratch_window_state_type_id;
}

GType
scratch_scratch_window_state_get_type (void)
{
	static gsize scratch_scratch_window_state_type_id__once = 0;
	if (g_once_init_enter (&scratch_scratch_window_state_type_id__once)) {
		GType scratch_scratch_window_state_type_id;
		scratch_scratch_window_state_type_id = scratch_scratch_window_state_get_type_once ();
		g_once_init_leave (&scratch_scratch_window_state_type_id__once, scratch_scratch_window_state_type_id);
	}
	return scratch_scratch_window_state_type_id__once;
}

 G_GNUC_NO_INLINE static GType
scratch_scratch_draw_spaces_state_get_type_once (void)
{
	static const GEnumValue values[] = {{SCRATCH_SCRATCH_DRAW_SPACES_STATE_NEVER, "SCRATCH_SCRATCH_DRAW_SPACES_STATE_NEVER", "never"}, {SCRATCH_SCRATCH_DRAW_SPACES_STATE_FOR_SELECTION, "SCRATCH_SCRATCH_DRAW_SPACES_STATE_FOR_SELECTION", "for-selection"}, {SCRATCH_SCRATCH_DRAW_SPACES_STATE_ALWAYS, "SCRATCH_SCRATCH_DRAW_SPACES_STATE_ALWAYS", "always"}, {SCRATCH_SCRATCH_DRAW_SPACES_STATE_CURRENT, "SCRATCH_SCRATCH_DRAW_SPACES_STATE_CURRENT", "current"}, {0, NULL, NULL}};
	GType scratch_scratch_draw_spaces_state_type_id;
	scratch_scratch_draw_spaces_state_type_id = g_enum_register_static ("ScratchScratchDrawSpacesState", values);
	return scratch_scratch_draw_spaces_state_type_id;
}

GType
scratch_scratch_draw_spaces_state_get_type (void)
{
	static gsize scratch_scratch_draw_spaces_state_type_id__once = 0;
	if (g_once_init_enter (&scratch_scratch_draw_spaces_state_type_id__once)) {
		GType scratch_scratch_draw_spaces_state_type_id;
		scratch_scratch_draw_spaces_state_type_id = scratch_scratch_draw_spaces_state_get_type_once ();
		g_once_init_leave (&scratch_scratch_draw_spaces_state_type_id__once, scratch_scratch_draw_spaces_state_type_id);
	}
	return scratch_scratch_draw_spaces_state_type_id__once;
}

