/* brackets-completion.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __PLUGINS_BRACKETS_COMPLETION_BRACKETS_COMPLETION_H__
#define __PLUGINS_BRACKETS_COMPLETION_BRACKETS_COMPLETION_H__

#include <libpeas.h>
#include "codecore.h"
#include <glib-object.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SCRATCH_PLUGINS_TYPE_BRACKETS_COMPLETION (scratch_plugins_brackets_completion_get_type ())
#define SCRATCH_PLUGINS_BRACKETS_COMPLETION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SCRATCH_PLUGINS_TYPE_BRACKETS_COMPLETION, ScratchPluginsBracketsCompletion))
#define SCRATCH_PLUGINS_BRACKETS_COMPLETION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SCRATCH_PLUGINS_TYPE_BRACKETS_COMPLETION, ScratchPluginsBracketsCompletionClass))
#define SCRATCH_PLUGINS_IS_BRACKETS_COMPLETION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SCRATCH_PLUGINS_TYPE_BRACKETS_COMPLETION))
#define SCRATCH_PLUGINS_IS_BRACKETS_COMPLETION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SCRATCH_PLUGINS_TYPE_BRACKETS_COMPLETION))
#define SCRATCH_PLUGINS_BRACKETS_COMPLETION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SCRATCH_PLUGINS_TYPE_BRACKETS_COMPLETION, ScratchPluginsBracketsCompletionClass))

typedef struct _ScratchPluginsBracketsCompletion ScratchPluginsBracketsCompletion;
typedef struct _ScratchPluginsBracketsCompletionClass ScratchPluginsBracketsCompletionClass;
typedef struct _ScratchPluginsBracketsCompletionPrivate ScratchPluginsBracketsCompletionPrivate;

struct _ScratchPluginsBracketsCompletion {
	PeasExtensionBase parent_instance;
	ScratchPluginsBracketsCompletionPrivate * priv;
};

struct _ScratchPluginsBracketsCompletionClass {
	PeasExtensionBaseClass parent_class;
};

GType scratch_plugins_brackets_completion_register_type (GTypeModule * module);
VALA_EXTERN GType scratch_plugins_brackets_completion_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ScratchPluginsBracketsCompletion, g_object_unref)
VALA_EXTERN ScratchPluginsBracketsCompletion* scratch_plugins_brackets_completion_new (void);
VALA_EXTERN ScratchPluginsBracketsCompletion* scratch_plugins_brackets_completion_construct (GType object_type);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
