/* config.c generated by valac 0.56.19, the Vala compiler
 * generated from config.vala, do not modify */

#include <stdlib.h>
#include <string.h>
#include <glib.h>

#define CONSTANTS_GETTEXT_PACKAGE "io.elementary.code"
#define CONSTANTS_PROJECT_NAME "io.elementary.code"
#define CONSTANTS_VERSION "8.3.1"
#define CONSTANTS_PLUGINDIR "/usr/lib/io.elementary.code/plugins"
#define CONSTANTS_INSTALL_PREFIX "/usr"
#define CONSTANTS_DATADIR "/usr/share"
#define CONSTANTS_LOCALEDIR "/usr/share/locale"
#define CONSTANTS_BRANCH ""
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

