/* editorconfig.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __PLUGINS_EDITORCONFIG_EDITORCONFIG_H__
#define __PLUGINS_EDITORCONFIG_EDITORCONFIG_H__

#include <libpeas.h>
#include "codecore.h"
#include <glib-object.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SCRATCH_PLUGINS_TYPE_EDITOR_CONFIG_PLUGIN (scratch_plugins_editor_config_plugin_get_type ())
#define SCRATCH_PLUGINS_EDITOR_CONFIG_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SCRATCH_PLUGINS_TYPE_EDITOR_CONFIG_PLUGIN, ScratchPluginsEditorConfigPlugin))
#define SCRATCH_PLUGINS_EDITOR_CONFIG_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SCRATCH_PLUGINS_TYPE_EDITOR_CONFIG_PLUGIN, ScratchPluginsEditorConfigPluginClass))
#define SCRATCH_PLUGINS_IS_EDITOR_CONFIG_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SCRATCH_PLUGINS_TYPE_EDITOR_CONFIG_PLUGIN))
#define SCRATCH_PLUGINS_IS_EDITOR_CONFIG_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SCRATCH_PLUGINS_TYPE_EDITOR_CONFIG_PLUGIN))
#define SCRATCH_PLUGINS_EDITOR_CONFIG_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SCRATCH_PLUGINS_TYPE_EDITOR_CONFIG_PLUGIN, ScratchPluginsEditorConfigPluginClass))

typedef struct _ScratchPluginsEditorConfigPlugin ScratchPluginsEditorConfigPlugin;
typedef struct _ScratchPluginsEditorConfigPluginClass ScratchPluginsEditorConfigPluginClass;
typedef struct _ScratchPluginsEditorConfigPluginPrivate ScratchPluginsEditorConfigPluginPrivate;

struct _ScratchPluginsEditorConfigPlugin {
	PeasExtensionBase parent_instance;
	ScratchPluginsEditorConfigPluginPrivate * priv;
};

struct _ScratchPluginsEditorConfigPluginClass {
	PeasExtensionBaseClass parent_class;
};

GType scratch_plugins_editor_config_plugin_register_type (GTypeModule * module);
VALA_EXTERN GType scratch_plugins_editor_config_plugin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ScratchPluginsEditorConfigPlugin, g_object_unref)
VALA_EXTERN ScratchPluginsEditorConfigPlugin* scratch_plugins_editor_config_plugin_new (void);
VALA_EXTERN ScratchPluginsEditorConfigPlugin* scratch_plugins_editor_config_plugin_construct (GType object_type);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
