/* detect-indent.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __PLUGINS_DETECT_INDENT_DETECT_INDENT_H__
#define __PLUGINS_DETECT_INDENT_DETECT_INDENT_H__

#include <libpeas.h>
#include "codecore.h"
#include <glib-object.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SCRATCH_PLUGINS_TYPE_DETECT_INDENT (scratch_plugins_detect_indent_get_type ())
#define SCRATCH_PLUGINS_DETECT_INDENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SCRATCH_PLUGINS_TYPE_DETECT_INDENT, ScratchPluginsDetectIndent))
#define SCRATCH_PLUGINS_DETECT_INDENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SCRATCH_PLUGINS_TYPE_DETECT_INDENT, ScratchPluginsDetectIndentClass))
#define SCRATCH_PLUGINS_IS_DETECT_INDENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SCRATCH_PLUGINS_TYPE_DETECT_INDENT))
#define SCRATCH_PLUGINS_IS_DETECT_INDENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SCRATCH_PLUGINS_TYPE_DETECT_INDENT))
#define SCRATCH_PLUGINS_DETECT_INDENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SCRATCH_PLUGINS_TYPE_DETECT_INDENT, ScratchPluginsDetectIndentClass))

typedef struct _ScratchPluginsDetectIndent ScratchPluginsDetectIndent;
typedef struct _ScratchPluginsDetectIndentClass ScratchPluginsDetectIndentClass;
typedef struct _ScratchPluginsDetectIndentPrivate ScratchPluginsDetectIndentPrivate;

struct _ScratchPluginsDetectIndent {
	PeasExtensionBase parent_instance;
	ScratchPluginsDetectIndentPrivate * priv;
};

struct _ScratchPluginsDetectIndentClass {
	PeasExtensionBaseClass parent_class;
};

GType scratch_plugins_detect_indent_register_type (GTypeModule * module);
VALA_EXTERN GType scratch_plugins_detect_indent_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ScratchPluginsDetectIndent, g_object_unref)
VALA_EXTERN ScratchPluginsDetectIndent* scratch_plugins_detect_indent_new (void);
VALA_EXTERN ScratchPluginsDetectIndent* scratch_plugins_detect_indent_construct (GType object_type);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
